@@ -14,12 +14,12 @@
 #ifndef ELEMENTPARSER_H
 #define ELEMENTPARSER_H
 
-#include <QtCore/QList>
+#include <QList>
+#include <QXmlAttributes>
+#include <QXmlDefaultHandler>
 
 #include "libkdeedu_science_export.h"
 
-#include <QtXml/QtXml>
-
 class Element;
 
 /**
@@ -34,11 +34,11 @@ public:
     ElementSaxParser();
     ~ElementSaxParser();
     bool startElement(const QString&, const QString &localName, const QString&,
-                      const QXmlAttributes &attrs);
+                      const QXmlAttributes &attrs) override;
 
-    bool endElement(const QString& namespaceURI, const QString &localName, const QString& qName);
+    bool endElement(const QString& namespaceURI, const QString &localName, const QString& qName) override;
 
-    bool characters(const QString &ch);
+    bool characters(const QString &ch) override;
 
     QList<Element*> getElements();
 
